﻿using System;
using System.Windows;
using System.Windows.Input;
using Infragistics.Controls.Grids;
using Infragistics.Documents.Excel;

namespace CorruptedEquipmentDictionary
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private ListDataValidationRule mRule;
		private bool InValidationErrorPrompt;

		public MainWindow()
		{
			InitializeComponent();
		}

		private void SpreadsheetContent_OnInitialized(object sender, EventArgs e)
		{
			for (var i = 0; i < 10; i++)
				SpreadsheetContent.ActiveWorksheet.Rows[i].Cells[4].Value = $"Value{i}";

			SpreadsheetContent.Workbook.NamedReferences.Add("Values", "=Sheet1!$E$1:$E$10", CellReferenceMode.A1,
				SpreadsheetContent.ActiveWorksheet);

			mRule = new ListDataValidationRule { ShowDropdown = true, AllowNull = true, ShowErrorMessageForInvalidValue = true };
			mRule.SetValuesFormula("=Values", null);

			for (var i = 0; i < 10; i++)
				SpreadsheetContent.ActiveWorksheet.Rows[i].Cells[0].DataValidationRule = mRule;
		}

		private void ButtonReadCell_Click(object sender, RoutedEventArgs e)
		{
			TextOutput.Text = SpreadsheetContent.ActiveWorksheet.Rows[SpreadsheetContent.ActiveCell.Row]
				                  .Cells[SpreadsheetContent.ActiveCell.Column].Value + " " +
			                  $"InValidationErrorPrompt = {InValidationErrorPrompt}";
		}

		private void SpreadsheetContent_OnLostKeyboardFocus(object sender, KeyboardFocusChangedEventArgs e)
		{
			if (!InValidationErrorPrompt)
				SpreadsheetContent.ExecuteCommand(SpreadsheetCommandType.ExitEditModeAndUpdateActiveCell, null);

			InValidationErrorPrompt = false;
		}

		private void SpreadsheetContent_OnEditModeValidationError(object sender, SpreadsheetEditModeValidationErrorEventArgs e)
		{
			InValidationErrorPrompt = true;
		}

		private void SpreadsheetContent_OnEditModeExited(object sender, SpreadsheetEditModeExitedEventArgs e)
		{
			InValidationErrorPrompt = false;
		}
	}
}
